<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Ayrıntılar</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Tahmin</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Doğru</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Büyük</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Yanlış</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Başarılı</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Oyun Bitti</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1/%n puan</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3/%n puan</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2/%n puan</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1/%n puan</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0/%n puan</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n puan</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>Maksinum skor devam eden 30 kelime sonrasında hesaplandı</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>d:sn</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n&apos;nci tahmin</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n saldırı</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Karmakarışık</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Klasik</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Doldurmalı</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Dayanıklılık</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Saldırı</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Paylaştırma</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Disiplin</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Süre 30 saniyeden başlar ve doğru cevaplar alındığında süre artar.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Süre 3 dakikadan başlar</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Süre 30 saniyeden başlar ve doğru cevaplar alındığında tekrar dolar.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Süre 45 saniyeden başlar ve her doğru cevap sonrası oyun 5 saniyeliğine durur.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>Oyun 3 yanlış tahmin sonrasında biter.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>Oyun 30 tahmin sonrasında biter</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Süre 30 saniyeden başlar ve tahminin doğruluğuna göre artar veya azalır.</translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Dosyadan zar okunamadı.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Dosyadan kelime listesi okunamadı.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Pano Dili</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Özel</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Seçiniz..</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;&gt;Önemli:&lt;/b&gt;Bu ayarlar siz yeni bir oyuna başladığınızda geçerli olacak.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Dil:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Zar:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Kalime listesi:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Sözlük:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Zar Dosyasını Seçiniz</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Kelime Listesi Dosyasını Seçiniz</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Uygulama dilini seçiniz:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Sistem Dili&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Not</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Değişikliklerin geçerli olması için lütfen bu uygulamayı tekrar başlatınız.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Yeni Oyun</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Kelime Sayısı:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Minimum Kelime Uzunluğu:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Düşük</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Orta</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Yüksek</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Rasgele</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n harf</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Yüksek Skorlar</translation>
    </message>
    <message>
        <source>&lt;b&gt;Name&lt;/b&gt;</source>
        <translation>&lt;b&gt;İsim&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Score&lt;/b&gt;</source>
        <translation>&lt;b&gt;Skor&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Date&lt;/b&gt;</source>
        <translation>&lt;b&gt;Tarih&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Timer&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mod&lt;/b&gt;</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>#%1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Emin Misiniz?</translation>
    </message>
    <message>
        <source>Clear high scores?</source>
        <translation>Yüksek skorları silmek istiyor musunuz?</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Oyun durduruldu&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Devam etmek için tıklayınız.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Lütfen bekleyiniz&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Oyun yükleniyor...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Yeni bir oyuna başlamak için tıklayınız.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Lütfen bekleyiniz&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Yeni pano oluşturuluyor...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Lütfen bekleyiniz&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Kelime listesi düzenleniyor...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Oyun</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>Yeni &amp;Oyun...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>&amp;Karıştırma</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Seçiniz...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>&amp;Paylaş...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Son</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Durdur</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Ayrıntılar</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Yüksek Skorlar</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Çıkış</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Ayarlar</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>&amp;Maksimum Skoru Göster</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Asla</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>&amp;Oyun Sonu</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Daima</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>&amp;Yanlış Kelimeleri Göster</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>&amp;Kelime Sayılarını Göster</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>&amp;Pano Dili</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Uygulama &amp;Dili...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Yardım</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Kontroller</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Hakkında</translation>
    </message>
    <message>
        <source>About &amp;Hspell</source>
        <translation>&amp;Hspell Hakkında</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>&amp;Qt Hakkında</translation>
    </message>
    <message>
        <source>About &amp;SCOWL</source>
        <translation>&amp;SCOWL Hakkında</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Hakkında</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt; oyununun tek kişilik versiyonudur.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Bu sürüm &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; lisansı altındadır.</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>İngilizce kelime listesi Kevin Atikson&apos;ın &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt;&apos;dan temel alınmıştır.</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Hebrew kelime listesi Nadav Har&apos;El and Dan Kenigsberg&apos;in &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt;&apos;den temel alınmıştır</translation>
    </message>
    <message>
        <source>About Hspell</source>
        <translation>Hspell Hakkında</translation>
    </message>
    <message>
        <source>About SCOWL</source>
        <translation>SCOWL Hakkında</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>İçe oyun aktar</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Tanglet Oyunları (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>İstenen oyunu başlatmada hata.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Dışa oyun aktar</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Emin Misiniz?</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Oyunu kapatmak istiyor musunuz?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Ayrıntılar</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Pano Büyüklüğü:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Geniş</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Kelime sıklığı:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Kelime Uzunluğu:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>%1 veya daha fazla kelime</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Oyun Türü:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Açıklama:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Kontroller</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Fare İle Oynarken:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Kelime seçimi:&lt;/b&gt; Kelimenin harflerine tıklanılır.&lt;br&gt;&lt;b&gt;Tahmin yürütme:&lt;/b&gt; Son seçilen harfe tıklanılır.&lt;br&gt;&lt;b&gt;Harfleri silme:&lt;/b&gt; Önceki seçilen harfe tıklanılır.&lt;br&gt;&lt;b&gt;Kelimeyi silme:&lt;/b&gt;İlk seçilen harfe çift tıklanılır.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Klavye İle Oynarken:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Kelime seçimi:&lt;/b&gt; Kelimenin harfi girilir.&lt;br&gt;&lt;b&gt;Tahmin yürütme:&lt;/b&gt; Enter&apos;a basılır.&lt;br&gt;&lt;b&gt;Kelimeyi silme:&lt;/b&gt; Ctrl+Backspace tuşlarına basılır.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Harfler:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Bulunan:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n puan</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
